@@ -181,15 +181,13 @@ vsf_ftpdataio_post_mark_connect(struct vsf_session* p_sess)
   }
   if (ret != 1)
   {
-    static struct mystr s_err_msg;
-    str_alloc_text(&s_err_msg, "SSL connection failed");
     if (tunable_require_ssl_reuse)
     {
-      str_append_text(&s_err_msg, "; session reuse required");
-      str_append_text(
-          &s_err_msg, ": see require_ssl_reuse option in vsftpd.conf man page");
+      vsf_cmdio_write_exit(p_sess, FTP_DATATLSBAD,
+                           "SSL connection failed: session reuse required", 1);
+    } else {
+      vsf_cmdio_write(p_sess, FTP_DATATLSBAD, "SSL connection failed");
     }
-    vsf_cmdio_write_str(p_sess, FTP_DATATLSBAD, &s_err_msg);
   }
   return ret;
 }
