@@ -439,6 +439,15 @@ process_post_login(struct vsf_session* p_sess)
     {
       /* Deliberately ignore to avoid NAT device bugs. ProFTPd does the same. */
     }
+    else if (str_equal_text(&p_sess->ftp_cmd_str, "GET") ||
+             str_equal_text(&p_sess->ftp_cmd_str, "POST") ||
+             str_equal_text(&p_sess->ftp_cmd_str, "HEAD") ||
+             str_equal_text(&p_sess->ftp_cmd_str, "OPTIONS") ||
+             str_equal_text(&p_sess->ftp_cmd_str, "CONNECT"))
+    {
+      vsf_cmdio_write_exit(p_sess, FTP_BADCMD,
+                           "HTTP protocol commands not allowed.", 1);
+    }
     else
     {
       vsf_cmdio_write(p_sess, FTP_BADCMD, "Unknown command.");
@@ -466,7 +475,7 @@ handle_pwd(struct vsf_session* p_sess)
   /* Enclose pathname in quotes */
   str_alloc_text(&s_pwd_res_str, "\"");
   str_append_str(&s_pwd_res_str, &s_cwd_buf_mangle_str);
-  str_append_text(&s_pwd_res_str, "\"");
+  str_append_text(&s_pwd_res_str, "\" is the current directory");
   vsf_cmdio_write_str(p_sess, FTP_PWDOK, &s_pwd_res_str);
 }
 
@@ -594,7 +603,7 @@ handle_pasv(struct vsf_session* p_sess, int is_epsv)
   {
     str_alloc_text(&s_pasv_res_str, "Entering Extended Passive Mode (|||");
     str_append_ulong(&s_pasv_res_str, (unsigned long) the_port);
-    str_append_text(&s_pasv_res_str, "|).");
+    str_append_text(&s_pasv_res_str, "|)");
     vsf_cmdio_write_str(p_sess, FTP_EPSVOK, &s_pasv_res_str);
     return;
   }
@@ -974,8 +983,7 @@ handle_port(struct vsf_session* p_sess)
     vsf_cmdio_write(p_sess, FTP_BADCMD, "Illegal PORT command.");
     return;
   }
-  the_port = vals[4] << 8;
-  the_port |= vals[5];
+  the_port = (unsigned short) ((vals[4] << 8) | vals[5]);
   vsf_sysutil_sockaddr_clone(&p_sess->p_port_sockaddr, p_sess->p_local_addr);
   vsf_sysutil_sockaddr_set_ipv4addr(p_sess->p_port_sockaddr, vals);
   vsf_sysutil_sockaddr_set_port(p_sess->p_port_sockaddr, the_port);
@@ -1736,7 +1744,7 @@ handle_eprt(struct vsf_session* p_sess)
   {
     if (!vsf_sysutil_sockaddr_addr_equal(p_sess->p_remote_addr,
                                          p_sess->p_port_sockaddr) ||
-        vsf_sysutil_is_port_reserved(port))
+        vsf_sysutil_is_port_reserved((unsigned short) port))
     {
       vsf_cmdio_write(p_sess, FTP_BADCMD, "Illegal EPRT command.");
       port_cleanup(p_sess);
@@ -1780,17 +1788,28 @@ get_unique_filename(struct mystr* p_outstr, const struct mystr* p_base_str)
    * two sessions are using the same file prefix at the same time.
    */
   static struct vsf_sysutil_statbuf* s_p_statbuf;
+  static struct mystr s_stou_str;
   unsigned int suffix = 1;
-  /* Do not add any suffix at all if the name is not taken. */
-  int retval = str_stat(p_base_str, &s_p_statbuf);
-  if (vsf_sysutil_retval_is_error(retval))
+  const struct mystr* p_real_base_str = p_base_str;
+  int retval;
+  if (str_isempty(p_real_base_str))
   {
-    str_copy(p_outstr, p_base_str);
-    return;
+    str_alloc_text(&s_stou_str, "STOU");
+    p_real_base_str = &s_stou_str;
+  }
+  else
+  {
+    /* Do not add any suffix at all if the name is not taken. */
+    retval = str_stat(p_real_base_str, &s_p_statbuf);
+    if (vsf_sysutil_retval_is_error(retval))
+    {
+       str_copy(p_outstr, p_real_base_str);
+       return;
+    }
   }
   while (1)
   {
-    str_copy(p_outstr, p_base_str);
+    str_copy(p_outstr, p_real_base_str);
     str_append_char(p_outstr, '.');
     str_append_ulong(p_outstr, suffix);
     retval = str_stat(p_outstr, &s_p_statbuf);
