@@ -71,13 +71,26 @@ ssl_slave(struct vsf_session* p_sess)
     }
     else if (cmd == PRIV_SOCK_DO_SSL_READ)
     {
-      str_trunc(&data_str, VSFTP_DATA_BUFSIZE);
+      int size = priv_sock_get_int(p_sess->ssl_slave_fd);
+      if (size <= 0 || size > VSFTP_DATA_BUFSIZE)
+      {
+        bug("bad size");
+      }
+      if (p_sess->data_fd == -1 || p_sess->p_data_ssl == 0)
+      {
+        bug("invalid state");
+      }
+      str_trunc(&data_str, (unsigned int) size);
       ret = ssl_read_into_str(p_sess, p_sess->p_data_ssl, &data_str);
       priv_sock_send_int(p_sess->ssl_slave_fd, ret);
       priv_sock_send_str(p_sess->ssl_slave_fd, &data_str);
     }
     else if (cmd == PRIV_SOCK_DO_SSL_WRITE)
     {
+      if (p_sess->data_fd == -1 || p_sess->p_data_ssl == 0)
+      {
+        bug("invalid state");
+      }
       priv_sock_get_str(p_sess->ssl_slave_fd, &data_str);
       ret = ssl_write(p_sess->p_data_ssl,
                       str_getbuf(&data_str),
@@ -93,6 +106,10 @@ ssl_slave(struct vsf_session* p_sess)
       }
       else
       {
+        if (p_sess->data_fd == -1 || p_sess->p_data_ssl == 0)
+        {
+          bug("invalid state");
+        }
         ret = ssl_data_close(p_sess);
         if (ret == 1)
         {
