@@ -69,6 +69,7 @@ struct str_locate_result
 {
   int found;
   unsigned int index;
+  char char_found;
 };
 
 struct str_locate_result str_locate_char(
@@ -81,6 +82,8 @@ struct str_locate_result str_locate_text(
   const struct mystr* p_str, const char* p_text);
 struct str_locate_result str_locate_text_reverse(
   const struct mystr* p_str, const char* p_text);
+struct str_locate_result str_locate_chars(
+  const struct mystr* p_str, const char* p_chars);
 
 void str_left(const struct mystr* p_str, struct mystr* p_out,
               unsigned int chars);
@@ -91,6 +94,7 @@ void str_mid_to_end(const struct mystr* p_str, struct mystr* p_out,
 
 char str_get_char_at(const struct mystr* p_str, const unsigned int indexx);
 int str_contains_space(const struct mystr* p_str);
+int str_all_space(const struct mystr* p_str);
 int str_contains_unprintable(const struct mystr* p_str);
 void str_replace_unprintable(struct mystr* p_str, char new_char);
 int str_atoi(const struct mystr* p_str);
